@@ -13,8 +13,10 @@ import json
 import pandas as pd
 import pickle
 from datetime import datetime as dt
+from pandas_datareader import data
 
 from napoleontoolbox.connector import shifting_utility
+from npxlogger import log
 # Local packages
 
 __all__ = ['NaPoleonXConnector']
@@ -55,6 +57,26 @@ def request_day_data_paquet(url, me_ts, ssj):
         print('no data')
     return dataframe
 
+def fetch_equity_daily_data(ticker=None, provider = 'yahoo', starting_date=None,running_date=None,local_root_directory=None):
+    yahoo_tickers_equivalents = {
+        'SPX' : '^GSPC',
+        'SX5E' : '^STOXX50E',
+    }
+    try:
+        yahoo_ticker = yahoo_tickers_equivalents[ticker]
+    except:
+        log.info('No yahoo ticker equivalent for this ticker. Check dictionary of yahoo tickers equivalents')
+
+    if provider == 'yahoo':
+        data_df = data.DataReader(yahoo_ticker, provider, starting_date, running_date)
+        data_df.columns = map(str.lower, data_df.columns)
+        filename = ticker+'_'+starting_date.strftime('%d_%b_%Y')+'_'+running_date.strftime('%d_%b_%Y')+'_daily_returns.pkl'
+        data_df.to_pickle(local_root_directory+filename)
+        return data_df
+    else:
+        log.info('This provider has not been set up yet.')
+        return
+
 def fetch_delayed_crypto_daily_data(frequence = 'daily', ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance', delay = 0):
     assert delay>0
     hourly_crypto_df = fetch_crypto_hourly_data(ssj=ssj,local_root_directory=local_root_directory,
@@ -124,6 +146,24 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
     return dataframe
 
 
+def fetch_rest_crypto_compare_last_minute_ohlc(ssj, against, limit = 1):
+    last_minute_url = f'https://min-api.cryptocompare.com/data/v2/histominute?fsym={ssj}&tsym={against}&limit={limit}'
+    r = requests.get(last_minute_url)
+    dataframe = None
+    try:
+        dataframe = pd.DataFrame(json.loads(r.text)['Data']['Data'])
+    except Exception as e:
+        print('no data')
+
+    dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
+    dataframe = dataframe.sort_values(by=['time'])
+    dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
+    dataframe = dataframe.set_index(dataframe['date'])
+    dataframe = dataframe.drop(columns=['date'])
+
+    return dataframe
+
+
 
 
 def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_return_pkl_filename_suffix=None, running_date= None, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, refetch_all=True, ssj_against='USDT', exchange = 'binance'):
