@@ -15,7 +15,7 @@ import math
 import numpy as np
 
 class MixerParalleLauncher():
-    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None,frequence=None,selected_algo=None,db_path_suffix = '_forecaster.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon', underlying=None,frequence=None,selected_algo=None,db_path_suffix = '_forecaster.sqlite', ss=[10], ns=[21], s_evals = [5], calibration_steps=[1000], transaction_costs = [False], optimize_thresholds=[True], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
         self.starting_date = starting_date
         self.running_date = running_date
         self.args = []
@@ -27,11 +27,12 @@ class MixerParalleLauncher():
             for n in ns:
                 for s_eval in s_evals:
                     for calibration_step in calibration_steps:
-                        for signal_type, params  in signal_idiosyncratic_paramaters.items():
-                            for param in params:
-                                self.args.append((self,self.seed,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
-                                self.key_args.append((self.seed,n,s,s_eval,calibration_step,signal_type,json.dumps(param, sort_keys=True)))
-                                self.counter = self.counter + 1
+                        for transaction_cost in transaction_costs:
+                            for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                                for param in params:
+                                    self.args.append((self,self.seed,n,s,s_eval,calibration_step,transaction_cost,signal_type,json.dumps(param, sort_keys=True)))
+                                    self.key_args.append((self.seed,n,s,s_eval,calibration_step,transaction_cost,signal_type,json.dumps(param, sort_keys=True)))
+                                    self.counter = self.counter + 1
         self.key_args.sort()
         self.counter = 1
         for me_arg in self.key_args:
@@ -69,7 +70,7 @@ class MixerParalleLauncher():
         self.empty_runs_to_investigate = []
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
 
-    def create_saving_key(self,seed, n, s, s_eval, calibration_step, signal_type, idios_string):
+    def create_saving_key(self,seed, n, s, s_eval, calibration_step, transaction_costs, signal_type, idios_string):
         idios = json.loads(idios_string)
         common_params ={
             'seed':seed,
@@ -77,6 +78,7 @@ class MixerParalleLauncher():
             's':s,
             's_eval':s_eval,
             'calibration_step':calibration_step,
+            'transaction_costs':transaction_costs,
             'signal_type' : signal_type,
             'discretization':0,
             'type': 'continuous'
