@@ -53,8 +53,13 @@ class SimpleSignalRunner(AbstractRunner):
         print('time range before filtering ')
         print(max(freqly_df.index))
         print(min(freqly_df.index))
-        freqly_df = freqly_df[freqly_df.index >= self.starting_date]
-        freqly_df = freqly_df[freqly_df.index <= self.running_date]
+        try:
+            freqly_df = freqly_df[freqly_df.index >= self.starting_date]
+            freqly_df = freqly_df[freqly_df.index <= self.running_date]
+        except:
+            freqly_df.index = pd.to_datetime(freqly_df.index)
+            freqly_df = freqly_df[freqly_df.index >= self.starting_date]
+            freqly_df = freqly_df[freqly_df.index <= self.running_date]
         print('time range after filtering ')
         print(max(freqly_df.index))
         print(min(freqly_df.index))
